@@ -45,10 +45,14 @@ main = hspec $ parallel $ do
           expected :: String = "foo\\bar"
       [i|foo\\#{var}|] `shouldBe` expected
 
-    it "should only esacpe verbatim segments a single time" $ do
+    it "should only escape verbatim segments a single time" $ do
       let expected :: String = "\\\\\\\\"
       [i|\\\\\\\\|] `shouldBe` expected
 
+    it "should parse TypeApplications" $ do
+      let expected :: String = "2"
+      [i|#{show @Int 2}|] `shouldBe` expected
+
     context "when using String as a parameter" $ do
       prop "just interpolating should be id" $
         \(UTF8S str) -> [i|#{str}|] == str
